<?php
/**
 * @author          jtotal <support@jtotal.org>
 * @link            https://jtotal.org
 * @copyright       Copyright © 2020 JTOTAL All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

defined('JPATH_PLATFORM') or die;

require_once  JPATH_PLUGINS . '/system/jtframework/autoload.php';

use JTFramework\Fa5;
use JTFramework\JTfunc;
use JTFramework\JTdebug;
use Joomla\CMS\Factory;
use Joomla\CMS\Form\FormField;
use Joomla\CMS\Language\Text;
use Joomla\CMS\String\PunycodeHelper;

/**
 * FORM to get User Key
 */
class JFormFieldJTkey extends FormField
{
    /**
     * The form field type.
     *
     * @var    string
     * @since  11.1
     */
    protected $type = 'jtkey';

    /**
     * Method to get the field input markup for e-mail addresses.
     *
     * @return  string  The field input markup.
     *
     * @since   11.1
     */
    protected function getInput()
    {
        
        //var_dump(Fa5::getFontGroup());
        $jinput = Factory::getApplication()->input;	       
        $component  = $jinput->get('option');

        // Translate placeholder text
        $hint = $this->translateHint ? Text::_($this->hint) : $this->hint;

        // Initialize some field attributes.
        $size         = !empty($this->size) ? ' size="' . $this->size . '"' : '';
        $maxLength    = !empty($this->maxLength) ? ' maxlength="' . $this->maxLength . '"' : '';
        $class        = !empty($this->class) ? ' class="input-xlarge ' . $this->class . '"' : ' class="input-xlarge"';
        $readonly     = $this->readonly ? ' readonly' : '';
        $disabled     = $this->disabled ? ' disabled' : '';
        $required     = $this->required ? ' required aria-required="true"' : '';
        $hint         = $hint ? ' placeholder="' . $hint . '"' : '';
        $autocomplete = !$this->autocomplete ? ' autocomplete="off"' : ' autocomplete="' . $this->autocomplete . '"';
        $autocomplete = $autocomplete == ' autocomplete="on"' ? '' : $autocomplete;
        $autofocus    = $this->autofocus ? ' autofocus' : '';
        $multiple     = $this->multiple ? ' multiple' : '';
        $spellcheck   = $this->spellcheck ? '' : ' spellcheck="false"';

        // Initialize JavaScript field attributes.
        $onchange = $this->onchange ? ' onchange="' . $this->onchange . '"' : '';

        $jinput = Factory::getApplication()->input;	       
        $component  = $jinput->get('option');

        switch ($component) {
            case 'com_fields':
                $onbuttonclick = 'onclick="Joomla.submitbutton(\'field.apply\')"';
                break;
            case 'com_modules':
                $onbuttonclick = 'onclick="Joomla.submitbutton(\'module.apply\')"';
                break;
            case 'com_plugins':
                $onbuttonclick = 'onclick="Joomla.submitbutton(\'plugin.apply\')"';
                break;
            case 'com_templates':
                $onbuttonclick = 'onclick="Joomla.submitbutton(\'style.apply\')"';
                break;
            default:
                $onbuttonclick = '';
        }

        $js = "
        
        ";

     

        if(JTfunc::isJ4()){

            //J4
            $html = '
            <div class="form-row align-items-center">

                <div class="col-auto">
                    <label class="sr-only" for="inlineFormInputGroup">Username</label>
                    <div class="input-group mb-2">
                        <input type="text" class="form-control" placeholder="" name="' . $this->name . '"' . $class . ' id="' . $this->id . '" value="'
                            . htmlspecialchars(PunycodeHelper::emailToUTF8($this->value), ENT_COMPAT, 'UTF-8') . '"' . $spellcheck . $size . $disabled . $readonly
                            . $onchange . $autocomplete . $multiple . $maxLength . $hint . $required . $autofocus . ' />
                     
                          <button class="btn btn-outline-success" type="button" '.$onbuttonclick.'>'.Text::_('JTOTAL_LICENSE_EMAIL_GO').'</button>
                        </div>
                </div>
 
            </div>';

        }else{

            //Load FA5
            fa5::getFaCDN();
            

            //J3
            $html = '<div class="input-append">';
                $html .= '<input type="text" name="' . $this->name . '"' . $class . ' id="' . $this->id . '" value="'. htmlspecialchars(PunycodeHelper::emailToUTF8($this->value), ENT_COMPAT, 'UTF-8') . '"' . $spellcheck . $size . $disabled . $readonly
                . $onchange . $autocomplete . $multiple . $maxLength . $hint . $required . $autofocus . ' />';
                $html .= '<button class="btn" type="button" '.$onbuttonclick.'>'.Text::_('JTOTAL_LICENSE_EMAIL_GO').'</button>';
            $html .= '</div><br>';
            

        }

        return $html;
        
    }
}
