<?php



defined('JPATH_BASE') or die;

use Joomla\CMS\HTML\HTMLHelper;
use JTFramework\JTfunc;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

if (is_file(JPATH_PLUGINS . '/system/jtframework/autoload.php'))
{
	require_once JPATH_PLUGINS . '/system/jtframework/autoload.php';
}else{
	$app = Factory::getApplication();
	$app->enqueueMessage(Text::_('JT_FW_NOT_FOUND'), 'error');
	return;
}


/**
 * Layout variables
 * -----------------
 * @var array   $displayData
 * @var string  $field
 * @var string  $autocomplete   Autocomplete attribute for the field.
 * @var boolean $autofocus      Is autofocus enabled?
 * @var string  $class          Classes for the input.
 * @var string  $description    Description of the field.
 * @var boolean $disabled       Is this field disabled?
 * @var string  $group          Group the field belongs to. <fields> section in form XML.
 * @var boolean $hidden         Is this field hidden in the form?
 * @var string  $hint           Placeholder for the field.
 * @var string  $id             DOM id of the field.
 * @var string  $label          Label of the field.
 * @var string  $labelclass     Classes to apply to the label.
 * @var boolean $multiple       Does this field support multiple values?
 * @var string  $name           Name of the input field.
 * @var string  $onchange       Onchange attribute for the field.
 * @var string  $onclick        Onclick attribute for the field.
 * @var string  $pattern        Pattern (Reg Ex) of value of the form field.
 * @var boolean $readonly       Is this field read only?
 * @var boolean $repeat         Allows extensions to duplicate elements.
 * @var boolean $required       Is this field required?
 * @var integer $size           Size attribute of the input.
 * @var boolean $spellcheck     Spellcheck state for the form field.
 * @var string  $validate       Validation rules to apply.
 * @var string  $value          Value attribute of the field.
 * @var array   $checkedOptions Options that will be set as checked.
 * @var boolean $hasValue       Has this field a value assigned?
 * @var array   $options        Options available for this field.
 * @var array   $inputType      Options available for this field.
 * @var string  $accept         File types that are accepted.
 * @var string  $prepend	
 * @var string  $append
 * @var string  $width
 */

extract($displayData);

// Including fallback code for HTML5 non supported browsers.
HTMLHelper::_('jquery.framework');
HTMLHelper::_('script', 'system/html5fallback.js', ['version' => 'auto', 'relative' => true, 'conditional' => 'lt IE 9']);

// Initialize some field attributes.
$attributes_range = [
	$class ? 'class="' . $class . '"' : '',
	$disabled ? 'disabled' : '',
	$readonly ? 'readonly' : '',
	! empty($onchange) ? 'onchange="' . $onchange . '"' : '',
	! empty($max) ? 'max="' . $max . '"' : '',
	! empty($step) ? 'step="' . $step . '"' : '',
	! empty($min) ? 'min="' . $min . '"' : '',
	$autofocus ? 'autofocus' : '',
];

if(!isset($max)) $max = 100;
$chars = strlen($max) ?: $size ?: 3;

$width = $chars * 8;

$attributes_number = [
	'class="input-mini text-right"',
	! empty($size) ? 'size="' . $size . '"' : '',
	$disabled ? 'disabled' : '',
	$readonly ? 'readonly' : '',
	strlen($hint) ? 'placeholder="' . htmlspecialchars($hint, ENT_COMPAT, 'UTF-8') . '"' : '',
	! empty($onchange) ? 'onchange="' . $onchange . '"' : '',
	isset($max) ? 'max="' . $max . '"' : '',
	! empty($step) ? 'step="' . $step . '"' : '',
	isset($min) ? 'min="' . $min . '"' : '',
	$required ? 'required aria-required="true"' : '',
	$autocomplete,
	$autofocus ? 'autofocus' : '',
	//$width ? 'style="width:'.$width.'px"' : '',
];



$classes = [];
if ($prepend)
{
	$classes[] = 'input-prepend input-group ';
}
if ($append)
{
	$classes[] = 'input-append input-group ';
}

if (strpos($prepend, 'icon-') === 0)
{
	$prepend = '<span class="' . $prepend . '"></span>';
}

if (strpos($append, 'icon-') === 0)
{
	$append = '<span class="' . $append . '"></span>';
}

if ($prepend && preg_match('#^[A-Z][A-Z0-9_]+$#', $prepend))
{
	$prepend = Text::_($prepend);
}

if ($append && preg_match('#^[A-Z][A-Z0-9_]+$#', $append))
{
	$append = Text::_($append);
}


$input = '<input class="form-control btn-light" type="text" name="' . $name . '" id="' . $id . '_input" value="' . $value . '"
       oninput="document.querySelector(\'input[data-for=\\\'' . $name . '\\\']\').value=this.value;"'
	. ' ' . implode(' ', $attributes_number) . ' />';
?>




<div class="tmrange_wrapper">
	
		<span class="<?php echo implode(' ', $classes); ?>">
			<?php if ($prepend): ?>
				<span class="add-on input-group-text bg-light text-dark"><?php echo $prepend; ?></span>
			<?php endif; ?>

			<?php echo $input; ?>

			<?php if ($append): ?>
				<span class="add-on input-group-text bg-light text-dark"><?php echo $append; ?></span>
			<?php endif; ?>
		</span>



	<input type="range" id="<?php echo $id; ?>" data-for="<?php echo $name; ?>" value="<?php echo $value; ?>"
		oninput="this.parentNode.querySelector('input').value=this.value;"
		<?php echo implode(' ', $attributes_range); ?> />

</div>

<?php
/* 
<input type="range" id="<?php echo $id.'_range'; ?>" data-for="<?php echo $name; ?>" value="<?php echo $value; ?>"
oninput="document.querySelector('input[name=\'<?php echo $name; ?>\']').value=this.value;"
oninput="document.querySelector('input[name=\'<?php echo $name; ?>\']').value=this.value;"
<?php echo implode(' ', $attributes_range); ?> />
 */
?>

